@@ -1,6 +1,6 @@
-#' GEVr Shape Parameter Profile Likelihood Estimation
+#' GEVr Shape Parameter Profile Likelihood Estimation for Stationary Models
 #'
-#' Computes the profile likelihood based confidence interval for the shape parameter of the GEVr model.
+#' Computes the profile likelihood based confidence interval for the shape parameter of the stationary GEVr model.
 #'
 #' @param z A class object returned from gevrFit.
 #' @param conf Confidence level to use. Defaults to 95 percent.
@@ -19,7 +19,9 @@
 #' \item{CI}{Profile likelihood based confidence interval for the shape parameter.}
 #' \item{ConfLevel}{The confidence level used.}
 #' @export
-gevrProfShape <- function(z, conf = .95, opt = c("Nelder-Mead", "SANN", "BFGS", "CG", "L-BFGS-B", "Brent")) {
+gevrProfShape <- function(z, conf = .95, opt = c("Nelder-Mead")) {
+  if(z$gumbel | !z$stationary)
+    stop("Object cannot be from a Gumbel and/or a nonstationary fit!")
   data <- as.matrix(z$data)
   theta <- as.numeric(z$par.ests)
   opt <- match.arg(opt)
